==> haskell-text-binary-0.2.1.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-binary
version:              0.2.1.1
visibility:           public
id:                   text-binary-0.2.1.1-KKFQBrzwBsf2AlclLIvX48
key:                  text-binary-0.2.1.1-KKFQBrzwBsf2AlclLIvX48
license:              BSD-2-Clause
maintainer:           waszczuk.kuba@gmail.com
author:               Jakub Waszczuk
stability:            provisional
homepage:             https://github.com/kawu/text-binary
synopsis:             Binary instances for text types
description:
    A compatibility layer providing Binary instances for strict
    and lazy text types for versions older than 1.2.1 of
    <https://hackage.haskell.org/package/text>.

category:             Data
abi:                  85ce00e9ec64977954daa0f392af5df5
exposed:              True
exposed-modules:      Data.Text.Binary
import-dirs:          /usr/lib/ghc-9.0.1/site-local/text-binary-0.2.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/text-binary-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/text-binary-0.2.1.1
hs-libraries:         HStext-binary-0.2.1.1-KKFQBrzwBsf2AlclLIvX48
depends:              base-4.15.0.0 binary-0.8.8.0 text-1.2.4.1
haddock-interfaces:   /usr/share/doc/haskell-text-binary/html/text-binary.haddock
haddock-html:         /usr/share/doc/haskell-text-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-binary-0.2.1.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-binary
version:              0.2.1.1
visibility:           public
id:                   text-binary-0.2.1.1-3Wlvkun294w4p1Ij9GsU3w
key:                  text-binary-0.2.1.1-3Wlvkun294w4p1Ij9GsU3w
license:              BSD-2-Clause
maintainer:           waszczuk.kuba@gmail.com
author:               Jakub Waszczuk
stability:            provisional
homepage:             https://github.com/kawu/text-binary
synopsis:             Binary instances for text types
description:
    A compatibility layer providing Binary instances for strict
    and lazy text types for versions older than 1.2.1 of
    <https://hackage.haskell.org/package/text>.

category:             Data
abi:                  038f9e1fce6ec2b078a27d0c689c2a9c
exposed:              True
exposed-modules:      Data.Text.Binary
import-dirs:          /usr/lib/ghc-9.0.2/site-local/text-binary-0.2.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/text-binary-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/text-binary-0.2.1.1
hs-libraries:         HStext-binary-0.2.1.1-3Wlvkun294w4p1Ij9GsU3w
depends:              base-4.15.1.0 binary-0.8.8.0 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-text-binary/html/text-binary.haddock
haddock-html:         /usr/share/doc/haskell-text-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
